## Chat Bot

<link rel="stylesheet" href="/assets/plugins/highlight/default.min.css">
<script src="/assets/plugins/highlight/highlight.min.js"></script>


```
{_{chatbot name="Custom bot"
          initial_message = "hi"
          platform  = "Groq (Free)"
          provider  = "1. Meta" 
          model     = "llama3-70b-8192" 
          edit_mode = "false" 
          channel   = "chatbot" 
           }}
```



{{chatbot name="Custom bot"
          initial_message = "hi"
          platform  = "Groq (Free)"
          provider  = "1. Meta" 
          model     = "llama3-70b-8192" 
          edit_mode = "false" 
          channel   = "chatbot" 
           }}

WebC__Form_Input


<script>
    window.hljs?.highlightAll()
</script>